/* SPDX-License-Identifier: BSD-3-Clause
 * Copyright(c) 2020 Mellanox Technologies, Ltd
 */
#include <string.h>

#include <rte_string_fns.h>

#include "eal_private.h"
#include "eal_memcfg.h"

/* early configuration structure, when memory config is not mmapped */
static struct rte_mem_config early_mem_config;

/* Address of global and public configuration */
static struct rte_config rte_config = {
	.mem_config = &early_mem_config,
};

/* platform-specific runtime dir */
static char runtime_dir[PATH_MAX];

/* internal configuration */
static struct internal_config internal_config;

/****** APIs for libnet ******/
static char sec_runtime_dir[RTE_MAX_SECONDARY][PATH_MAX];
static struct rte_config sec_rte_config[RTE_MAX_SECONDARY];
static struct internal_config sec_internal_config[RTE_MAX_SECONDARY];

char *
rte_eal_get_runtime_dir(void)
{
	return runtime_dir;
}

char *
rte_eal_sec_get_runtime_dir(const int sec_idx)
{
	return sec_runtime_dir[sec_idx];
}

static int
set_runtime_dir(char *dst_dir, char *src_dir, size_t size)
{
	size_t str_size;

	str_size = strlcpy(dst_dir, src_dir, size);
	if (str_size >= size) {
		RTE_LOG(ERR, EAL, "Runtime directory string too long\n");
		return -1;
	}

	return 0;
}

int
eal_sec_set_runtime_dir(char *run_dir, size_t size, const int sec_idx)
{
	return set_runtime_dir(sec_runtime_dir[sec_idx], run_dir, size);
}

int
eal_set_runtime_dir(char *run_dir, size_t size)
{
	return set_runtime_dir(runtime_dir, run_dir, size);
}

/* Return a pointer to the configuration structure */
struct rte_config *
rte_eal_get_configuration(void)
{
	return &rte_config;
}

struct rte_config *
rte_eal_sec_get_configuration(const int sec_idx)
{
	return &sec_rte_config[sec_idx];
}

struct internal_config *
rte_eal_sec_get_internal_config(const int sec_idx)
{
	return &sec_internal_config[sec_idx];
}

/* Return a pointer to the internal configuration structure */
struct internal_config *
eal_get_internal_configuration(void)
{
	return &internal_config;
}

enum rte_iova_mode
rte_eal_iova_mode(void)
{
	return rte_eal_get_configuration()->iova_mode;
}

enum rte_proc_type_t
rte_eal_process_type(void)
{
	return rte_config.process_type;
}

/* Return user provided mbuf pool ops name */
const char *
rte_eal_mbuf_user_pool_ops(void)
{
	return internal_config.user_mbuf_pool_ops_name;
}

/* return non-zero if hugepages are enabled. */
int
rte_eal_has_hugepages(void)
{
	return !internal_config.no_hugetlbfs;
}

int
rte_eal_has_pci(void)
{
	return !internal_config.no_pci;
}
